import { DOMRect, RectProps } from './types';
export declare type Orientation = 'top' | 'left' | 'bottom' | 'right';
export declare type HAlignment = 'start' | 'center' | 'end';
export declare type VAlignment = 'top' | 'middle' | 'bottom';
export interface Positioned extends Partial<RectProps> {
    fits: boolean;
}
export interface Lane extends Partial<RectProps> {
    name: Orientation;
}
export interface HPositionedSide {
    start: Positioned;
    center: Positioned;
    end: Positioned;
}
export interface VPositionedSide {
    top: Positioned;
    middle: Positioned;
    bottom: Positioned;
}
export interface PositionedSide {
    top: HPositionedSide;
    middle: HPositionedSide;
    bottom: HPositionedSide;
    start: VPositionedSide;
    center: VPositionedSide;
    end: VPositionedSide;
}
export interface RingsideInterface {
    top(): PositionedSide;
    right(): PositionedSide;
    bottom(): PositionedSide;
    left(): PositionedSide;
}
declare class Ringside implements RingsideInterface {
    readonly innerBounds: DOMRect;
    readonly outerBounds: DOMRect;
    readonly height: number;
    readonly width: number;
    readonly topLane: Lane;
    readonly rightLane: Lane;
    readonly bottomLane: Lane;
    readonly leftLane: Lane;
    orientations: Orientation[];
    hAlignments: HAlignment[];
    vAlignments: VAlignment[];
    constructor(innerBounds: DOMRect, outerBounds: DOMRect, height: number, width: number);
    top(): PositionedSide;
    bottom(): PositionedSide;
    right(): PositionedSide;
    left(): PositionedSide;
    private lanes();
    private positions(orientation);
    private alignedPosition(orientation, hAlignment, vAlignment);
    private boundingBox(orientation, alignment);
    private boundingWidth(orientation, alignment);
    private boundingX(orientation, alignment, boundingWidth);
    private fitsBounds(bounds);
    private alignInBounds(bounds, orientation, hAlignment, vAlignment);
    private alignHorizontal(bounds, orientation, alignment);
    private alignVertical(bounds, orientation, alignment);
    private relativeProp(props, orientation, offset?);
    private relativeProps(orientation);
    private relativeLane(orientation, alignment);
}
export default Ringside;
